@@ -1,12 +1,12 @@
 import { equals } from 'ramda';
 
+import { ComplexContent, SimpleContent } from './stories/contents';
 import {
   ComplexData,
-  complexData,
   SimpleData,
+  complexData,
   simpleData
 } from './stories/datas';
-import { ComplexContent, SimpleContent } from './stories/contents';
 
 import { Node, StandaloneTree, TreeProps } from '.';
 
@@ -23,10 +23,8 @@ const validateTree = (tree): void => {
   });
 };
 
-interface InitializeProps extends Pick<
-  TreeProps<SimpleData | ComplexData>,
-  'treeLink' | 'children'
-> {
+interface InitializeProps
+  extends Pick<TreeProps<SimpleData | ComplexData>, 'treeLink' | 'children'> {
   data?: Node<SimpleData | ComplexData>;
   isDefaultExpanded?: (data: SimpleData | ComplexData) => boolean;
 }
@@ -37,6 +35,8 @@ const initializeStandaloneTree = ({
   treeLink,
   children = SimpleContent
 }: InitializeProps): void => {
+  cy.adjustViewport();
+
   cy.mount({
     Component: (
       <div style={{ height: '99vh' }}>
@@ -170,4 +170,28 @@ describe('Complex data tree', () => {
 
     cy.makeSnapshot();
   });
+
+  it('displays the tree with step links when a prop is set', () => {
+    initializeStandaloneTree({
+      treeLink: {
+        type: 'step'
+      }
+    });
+
+    cy.contains('T').should('be.visible');
+
+    cy.makeSnapshot();
+  });
+
+  it('displays the tree with line links when a prop is set', () => {
+    initializeStandaloneTree({
+      treeLink: {
+        type: 'line'
+      }
+    });
+
+    cy.contains('T').should('be.visible');
+
+    cy.makeSnapshot();
+  });
 });
