@@ -1,12 +1,12 @@
-import * as React from 'react';
+import { ForwardedRef, forwardRef } from 'react';
 
 interface Props extends Record<string, unknown> {
   Content: (props) => JSX.Element;
   isInDragOverlay?: boolean;
 }
 
-const Item = React.forwardRef(
-  ({ Content, ...props }: Props, ref: React.ForwardedRef<HTMLDivElement>) => {
+const Item = forwardRef(
+  ({ Content, ...props }: Props, ref: ForwardedRef<HTMLDivElement>) => {
     return <Content {...props} itemRef={ref} />;
   }
 );
