@@ -38,6 +38,8 @@ class CfgNagios
      */
     public static function getConfiguration(string $name, int $serverID): array
     {
+        $configName = strtolower(str_replace(' ', '-', $name));
+
         return [
             'nagios_name' => $name,
             'use_timezone' => null,
@@ -81,7 +83,7 @@ class CfgNagios
             'auto_reschedule_checks' => '0',
             'auto_rescheduling_interval' => '30',
             'auto_rescheduling_window' => '180',
-            'enable_flap_detection' => '0',
+            'enable_flap_detection' => '1',
             'low_service_flap_threshold' => '25.0',
             'high_service_flap_threshold' => '50.0',
             'low_host_flap_threshold' => '25.0',
@@ -111,7 +113,7 @@ class CfgNagios
             'nagios_server_id' => $serverID,
             'enable_predictive_host_dependency_checks' => '1',
             'enable_predictive_service_dependency_checks' => '1',
-            'host_down_disable_service_checks' => '0',
+            'host_down_disable_service_checks' => '1',
             'cached_host_check_horizon' => '15',
             'cached_service_check_horizon' => '15',
             'enable_environment_macros' => '0',
@@ -124,6 +126,7 @@ class CfgNagios
             'cfg_file' => 'centengine.cfg',
             'log_pid' => '1',
             'logger_version' => 'log_v2_enabled',
+            'broker_module_cfg_file' => "/etc/centreon-broker/{$configName}-module.json",
         ];
     }
 }
