@@ -31,7 +31,7 @@ class ContactTemplate
      */
     public function __construct(
         private int $id,
-        private string $name
+        private string $name,
     ) {
     }
 
