@@ -43,6 +43,7 @@ class Macro
     private bool $shouldBeEncrypted = false;
 
     /**
+     * @param int $id|null
      * @param int $ownerId
      * @param string $name
      * @param string $value
@@ -50,12 +51,16 @@ class Macro
      * @throws AssertionFailedException
      */
     public function __construct(
+        private readonly ?int $id,
         private readonly int $ownerId,
         private string $name,
         private string $value,
     ) {
         $this->shortName = (new \ReflectionClass($this))->getShortName();
 
+        if ($id !== null) {
+            Assertion::positiveInt($id, "{$this->shortName}::id");
+        }
         Assertion::positiveInt($ownerId, "{$this->shortName}::ownerId");
         Assertion::notEmptyString($this->name, "{$this->shortName}::name");
         $this->name = mb_strtoupper($name);
@@ -63,6 +68,11 @@ class Macro
         Assertion::maxLength($this->value, self::MAX_VALUE_LENGTH, "{$this->shortName}::value");
     }
 
+    public function getId(): ?int
+    {
+        return $this->id;
+    }
+
     public function getOwnerId(): int
     {
         return $this->ownerId;
