@@ -23,6 +23,7 @@ declare(strict_types=1);
 
 namespace Core\ResourceAccess\Application\Providers;
 
+use Core\Common\Domain\Exception\RepositoryException;
 use Core\ResourceAccess\Domain\Model\DatasetFilter\ResourceNamesById;
 
 interface DatasetProviderInterface
@@ -37,6 +38,8 @@ interface DatasetProviderInterface
     /**
      * @param int[] $resourceIds
      *
+     * @throws RepositoryException
+     *
      * @return int[]
      */
     public function areResourcesValid(array $resourceIds): array;
@@ -44,6 +47,8 @@ interface DatasetProviderInterface
     /**
      * @param int[] $ids
      *
+     * @throws RepositoryException
+     *
      * @return ResourceNamesById
      */
     public function findResourceNamesByIds(array $ids): ResourceNamesById;
