@@ -1,6 +1,5 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 import { initializeWebSsoUserAndGetLoginPage } from '../common';
 
 before(() => {
@@ -36,7 +35,10 @@ Given('an administrator logged in the platform', () => {
 });
 
 When('the administrator sets authentication mode to Web SSO only', () => {
-  cy.visit(PAGES.configuration.authentication)
+  cy.navigateTo({
+    page: 'Authentication',
+    rootItemNumber: 4
+  })
     .get('div[role="tablist"] button:nth-child(3)')
     .click();
   cy.wait('@getWebSSOProvider');
