@@ -1,16 +1,15 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 
 beforeEach(() => {
   cy.startContainers();
-  cy.intercept({
-    method: 'GET',
-    url: '/centreon/include/common/userTimezone.php'
-  }).as('getUserTimezone');
   cy.intercept({
     method: 'GET',
     url: '/centreon/api/internal.php?object=centreon_topology&action=navigationList'
   }).as('getNavigationList');
+  cy.intercept({
+    method: 'GET',
+    url: '/centreon/include/common/userTimezone.php'
+  }).as('getTimeZone');
 });
 
 Given('a user is logged in Centreon', () => {
@@ -18,28 +17,20 @@ Given('a user is logged in Centreon', () => {
 });
 
 Then('a service category is configured', () => {
-  cy.visit(PAGES.configuration.servicesCategoriesLegacy);
+  cy.navigateTo({
+    page: 'Categories',
+    rootItemNumber: 3,
+    subMenu: 'Services'
+  });
+  cy.waitForElementInIframe('#main-content', 'input[name="searchSC"]');
+  cy.getIframeBody().contains('Add').click();
+  cy.waitForElementInIframe('#main-content', 'input[name="sc_name"]');
+  cy.getIframeBody().find('input[name="sc_name"]').type('test');
+
   cy.getIframeBody()
-    .find('tr.ToolbarTR')
-    .find('.btc.bt_success')
-    .contains('Add')
-    .click();
-  cy.get('iframe#main-content')
-    .its('0.contentDocument.body')
-    .find('table > tbody > tr.list_one > td.FormRowValue')
-    .find('input[name="sc_name"]')
-    .type('test');
-  cy.getIframeBody()
-    .find('table tr.list_two td.FormRowValue')
     .find('input[name="sc_description"]')
     .type('test description');
-  cy.get('iframe#main-content')
-    .its('0.contentDocument.body')
-    .find('table tr.list_two')
-    .find('td.FormRowValue')
-    .find('select#sc_svcTpl')
-    .next()
-    .click();
+  cy.getIframeBody().find('select#sc_svcTpl').next().click();
   cy.getIframeBody().contains('Ping-LAN').click();
   cy.getIframeBody()
     .find('div#validForm')
@@ -49,14 +40,10 @@ Then('a service category is configured', () => {
 });
 
 When('the user change the properties of a service category', () => {
-  cy.get('iframe#main-content')
-    .its('0.contentDocument.body')
-    .find('table tbody')
-    .contains('test')
-    .click();
-  cy.get('iframe#main-content')
-    .its('0.contentDocument.body')
-    .find('table tr.list_two td.FormRowValue')
+  cy.waitForElementInIframe('#main-content', 'input[name="searchSC"]');
+  cy.getIframeBody().contains('test').click();
+  cy.waitForElementInIframe('#main-content', 'input[name="sc_description"]');
+  cy.getIframeBody()
     .find('input[name="sc_description"]')
     .clear()
     .type('test description modified');
@@ -68,21 +55,19 @@ When('the user change the properties of a service category', () => {
 });
 
 Then('the properties are updated', () => {
-  cy.get('iframe#main-content')
-    .its('0.contentDocument.body')
-    .find('table tbody')
-    .contains('test description modified');
+  cy.waitForElementInIframe('#main-content', 'input[name="searchSC"]');
+  cy.getIframeBody().contains('test description modified');
 });
 
 When('the user duplicate a service category', () => {
-  cy.visit(PAGES.configuration.servicesCategoriesLegacy);
   cy.get('iframe#main-content')
     .its('0.contentDocument.body')
     .find('table tbody')
-    .find('tr.list_one')
+    .find('tr.list_one, tr.list_two')
+    .contains('td', 'Ping')
+    .parent()
     .find('td.ListColPicker')
     .find('div.md-checkbox')
-    .eq(1)
     .click();
   cy.get('iframe#main-content')
     .its('0.contentDocument.body')
@@ -103,38 +88,29 @@ When('the user duplicate a service category', () => {
 });
 
 Then('the new service category has the same properties', () => {
+  cy.wait('@getTimeZone');
   cy.get('iframe#main-content')
     .its('0.contentDocument.body')
     .find('table tbody')
     .contains('Ping_1')
     .should('be.visible');
-  cy.get('iframe#main-content')
-    .its('0.contentDocument.body')
-    .find('table tbody')
-    .contains('Ping_1')
-    .click();
-  cy.get('iframe#main-content')
-    .its('0.contentDocument.body')
-    .find('table > tbody > tr.list_one > td.FormRowValue')
-    .find('input[value="Ping_1"]')
-    .should('exist');
-  cy.getIframeBody()
-    .find('table tr.list_two td.FormRowValue')
-    .find('input[value="ping"]')
-    .should('exist');
+  cy.getIframeBody().contains('Ping_1').click();
+  cy.waitForElementInIframe('#main-content', 'input[name="sc_description"]');
+  cy.getIframeBody().find('input[value="Ping_1"]').should('exist');
+  cy.getIframeBody().find('input[value="ping"]').should('exist');
   cy.getIframeBody().contains('Ping-LAN').should('exist');
   cy.getIframeBody().contains('Ping-WAN').should('exist');
 });
 
 When('the user delete a service category', () => {
-  cy.visit(PAGES.configuration.servicesCategoriesLegacy);
   cy.get('iframe#main-content')
     .its('0.contentDocument.body')
     .find('table tbody')
-    .find('tr.list_two')
+    .find('tr.list_one, tr.list_two')
+    .contains('td', 'test')
+    .parent()
     .find('td.ListColPicker')
     .find('div.md-checkbox')
-    .eq(1)
     .click();
   cy.get('iframe#main-content')
     .its('0.contentDocument.body')
@@ -155,16 +131,14 @@ When('the user delete a service category', () => {
 });
 
 Then('the deleted service category is not displayed in the list', () => {
+  cy.wait('@getTimeZone');
+  cy.window().then((win) => win.location.reload());
   cy.get('iframe#main-content')
     .its('0.contentDocument.body')
     .find('table.ListTable tbody')
     .children()
     .should('have.length', 5);
-  cy.get('iframe#main-content')
-    .its('0.contentDocument.body')
-    .find('table.ListTable tbody')
-    .contains('test')
-    .should('not.exist');
+  cy.getIframeBody().contains('test').should('not.exist');
 });
 
 afterEach(() => {
