@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -55,7 +55,7 @@ beforeEach(function (): void {
             ->setWarningHighThreshold(50)
             ->setWarningLowThreshold(0)
             ->setCriticalHighThreshold(100)
-            ->setCriticalLowThreshold(50)
+            ->setCriticalLowThreshold(50),
     ];
 });
 
@@ -197,4 +197,4 @@ it('should present an FindMetricsByServiceResponse when metrics are correctly fo
         ->and($presenter->data->metricsDto[1]->warningLowThreshold)->toBe(0.0)
         ->and($presenter->data->metricsDto[1]->criticalHighThreshold)->toBe(100.0)
         ->and($presenter->data->metricsDto[1]->criticalLowThreshold)->toBe(50.0);
-});
\ No newline at end of file
+});
