@@ -288,22 +288,23 @@ class CentreonHostCategory extends CentreonSeverityAbstract
      */
     private function findHostCategories(): array
     {
-        $statement = $this->db->query(<<<'SQL'
-            SELECT hc.hc_name, hc.level, host.host_name,
-                   CONCAT(dir.dir_name, '/' ,img.img_path) AS img_path
-            FROM hostcategories hc
-            LEFT JOIN hostcategories_relation rel
-                ON rel.hostcategories_hc_id = hc.hc_id
-            LEFT JOIN host
-                ON host.host_id = rel.host_host_id
-            LEFT JOIN view_img_dir_relation rel2
-                ON rel2.img_img_id = hc.icon_id
-            LEFT JOIN view_img img
-                ON img.img_id = rel2.img_img_id
-            LEFT JOIN view_img_dir dir
-                ON dir.dir_id = rel2.dir_dir_parent_id
-            ORDER BY hc.hc_name
-            SQL
+        $statement = $this->db->query(
+            <<<'SQL'
+                SELECT hc.hc_name, hc.level, host.host_name,
+                       CONCAT(dir.dir_name, '/' ,img.img_path) AS img_path
+                FROM hostcategories hc
+                LEFT JOIN hostcategories_relation rel
+                    ON rel.hostcategories_hc_id = hc.hc_id
+                LEFT JOIN host
+                    ON host.host_id = rel.host_host_id
+                LEFT JOIN view_img_dir_relation rel2
+                    ON rel2.img_img_id = hc.icon_id
+                LEFT JOIN view_img img
+                    ON img.img_id = rel2.img_img_id
+                LEFT JOIN view_img_dir dir
+                    ON dir.dir_id = rel2.dir_dir_parent_id
+                ORDER BY hc.hc_name
+                SQL
         );
         $hostCategories = [];
         while (($result = $statement->fetch(PDO::FETCH_ASSOC)) !== false) {
