@@ -1,33 +1,19 @@
 <?php
+
 /*
- * Copyright 2005-2019 CENTREON
- * Centreon is developed by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give CENTREON
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of CENTREON choice, provided that
- * CENTREON also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
@@ -47,12 +33,16 @@ class ProceduresProxy
 {
     /** @var procedures */
     public $proc;
+
     /** @var CentreonDB */
     private $DB;
+
     /** @var mixed */
     private $wikiUrl;
+
     /** @var CentreonHost */
     private $hostObj;
+
     /** @var CentreonService */
     private $serviceObj;
 
@@ -74,110 +64,13 @@ class ProceduresProxy
         $this->proc = new procedures($this->DB);
     }
 
-    /**
-     * @param string $hostName
-     *
-     * @return int
-     * @throws PDOException
-     */
-    private function getHostId($hostName)
-    {
-        $statement = $this->DB->prepare("SELECT host_id FROM host WHERE host_name LIKE :hostName");
-        $statement->bindValue(':hostName', $hostName, \PDO::PARAM_STR);
-        $statement->execute();
-        $hostId = 0;
-        if ($row = $statement->fetch()) {
-            $hostId = $row["host_id"];
-        }
-        return $hostId;
-    }
-
-    /**
-     * Get service id from hostname and service description
-     *
-     * @param string $hostName
-     * @param string $serviceDescription
-     *
-     * @return int|null
-     * @throws PDOException
-     */
-    private function getServiceId($hostName, $serviceDescription): ?int
-    {
-        /*
-         * Get Services attached to hosts
-         */
-        $statement = $this->DB->prepare(
-            "SELECT s.service_id FROM host h, service s, host_service_relation hsr " .
-            "WHERE hsr.host_host_id = h.host_id " .
-            "AND hsr.service_service_id = service_id " .
-            "AND h.host_name LIKE :hostName " .
-            "AND s.service_description LIKE :serviceDescription "
-        );
-        $statement->bindValue(':hostName', $hostName, \PDO::PARAM_STR);
-        $statement->bindValue(':serviceDescription', $serviceDescription, \PDO::PARAM_STR);
-        $statement->execute();
-        if ($row = $statement->fetch()) {
-            return (int) $row["service_id"];
-        }
-        $statement->closeCursor();
-
-        /*
-         * Get Services attached to hostgroups
-         */
-        $statement = $this->DB->prepare(
-            "SELECT s.service_id FROM hostgroup_relation hgr, host h, service s, host_service_relation hsr " .
-            "WHERE hgr.host_host_id = h.host_id " .
-            "AND hsr.hostgroup_hg_id = hgr.hostgroup_hg_id " .
-            "AND h.host_name LIKE :hostName " .
-            "AND service_id = hsr.service_service_id " .
-            "AND service_description LIKE :serviceDescription "
-        );
-        $statement->bindValue(':hostName', $hostName, \PDO::PARAM_STR);
-        $statement->bindValue(':serviceDescription', $serviceDescription, \PDO::PARAM_STR);
-        $statement->execute();
-        if ($row = $statement->fetch()) {
-            return (int) $row["service_id"];
-        }
-        $statement->closeCursor();
-
-        return null;
-    }
-
-    /**
-     * Get service notes url
-     *
-     * @param int $serviceId
-     *
-     * @return string|null
-     * @throws PDOException
-     */
-    private function getServiceNotesUrl(int $serviceId): ?string
-    {
-        $notesUrl = null;
-
-        $statement = $this->DB->prepare(
-            "SELECT esi_notes_url " .
-            "FROM extended_service_information " .
-            "WHERE service_service_id = :serviceId"
-        );
-
-        $statement->bindValue(':serviceId', $serviceId, \PDO::PARAM_INT);
-        $statement->execute();
-
-        if ($row = $statement->fetch()) {
-            $notesUrl = $row['esi_notes_url'];
-        }
-
-        return $notesUrl;
-    }
-
     /**
      * Get host url
      *
      * @param string $hostName
      *
-     * @return string|null
      * @throws PDOException
+     * @return string|null
      */
     public function getHostUrl($hostName): ?string
     {
@@ -195,7 +88,7 @@ class ProceduresProxy
         );
 
         if (isset($hostProperties['ehi_notes_url'])) {
-            return $this->wikiUrl . "/index.php?title=Host_:_" . $hostProperties['host_name'];
+            return $this->wikiUrl . '/index.php?title=Host_:_' . $hostProperties['host_name'];
         }
 
         $templates = $this->hostObj->getTemplateChain($hostId);
@@ -208,7 +101,7 @@ class ProceduresProxy
             );
 
             if (isset($inheritedHostProperties['ehi_notes_url'])) {
-                return $this->wikiUrl . "/index.php?title=Host-Template_:_" . $inheritedHostProperties['host_name'];
+                return $this->wikiUrl . '/index.php?title=Host-Template_:_' . $inheritedHostProperties['host_name'];
             }
         }
 
@@ -221,8 +114,8 @@ class ProceduresProxy
      * @param string $hostName
      * @param string $serviceDescription
      *
-     * @return string|null
      * @throws PDOException
+     * @return string|null
      */
     public function getServiceUrl($hostName, $serviceDescription): ?string
     {
@@ -234,27 +127,117 @@ class ProceduresProxy
             return null;
         }
 
-        /*
-         * Check Service
-         */
+        // Check Service
         $notesUrl = $this->getServiceNotesUrl($serviceId);
         if ($notesUrl !== null) {
-            return $this->wikiUrl . "/index.php?title=Service_:_" . $hostName . "_/_" . $serviceDescription;
+            return $this->wikiUrl . '/index.php?title=Service_:_' . $hostName . '_/_' . $serviceDescription;
         }
 
-        /*
-         * Check service Template
-         */
+        // Check service Template
         $serviceId = $this->getServiceId($hostName, $serviceDescription);
         $templates = $this->serviceObj->getTemplatesChain($serviceId);
         foreach (array_reverse($templates) as $templateId) {
             $templateDescription = $this->serviceObj->getServiceDesc($templateId);
             $notesUrl = $this->getServiceNotesUrl((int) $templateId);
             if ($notesUrl !== null) {
-                return $this->wikiUrl . "/index.php?title=Service-Template_:_" . $templateDescription;
+                return $this->wikiUrl . '/index.php?title=Service-Template_:_' . $templateDescription;
             }
         }
 
         return $this->getHostUrl($hostName);
     }
+
+    /**
+     * @param string $hostName
+     *
+     * @throws PDOException
+     * @return int
+     */
+    private function getHostId($hostName)
+    {
+        $statement = $this->DB->prepare('SELECT host_id FROM host WHERE host_name LIKE :hostName');
+        $statement->bindValue(':hostName', $hostName, PDO::PARAM_STR);
+        $statement->execute();
+        $hostId = 0;
+        if ($row = $statement->fetch()) {
+            $hostId = $row['host_id'];
+        }
+
+        return $hostId;
+    }
+
+    /**
+     * Get service id from hostname and service description
+     *
+     * @param string $hostName
+     * @param string $serviceDescription
+     *
+     * @throws PDOException
+     * @return int|null
+     */
+    private function getServiceId($hostName, $serviceDescription): ?int
+    {
+        // Get Services attached to hosts
+        $statement = $this->DB->prepare(
+            'SELECT s.service_id FROM host h, service s, host_service_relation hsr '
+            . 'WHERE hsr.host_host_id = h.host_id '
+            . 'AND hsr.service_service_id = service_id '
+            . 'AND h.host_name LIKE :hostName '
+            . 'AND s.service_description LIKE :serviceDescription '
+        );
+        $statement->bindValue(':hostName', $hostName, PDO::PARAM_STR);
+        $statement->bindValue(':serviceDescription', $serviceDescription, PDO::PARAM_STR);
+        $statement->execute();
+        if ($row = $statement->fetch()) {
+            return (int) $row['service_id'];
+        }
+        $statement->closeCursor();
+
+        // Get Services attached to hostgroups
+        $statement = $this->DB->prepare(
+            'SELECT s.service_id FROM hostgroup_relation hgr, host h, service s, host_service_relation hsr '
+            . 'WHERE hgr.host_host_id = h.host_id '
+            . 'AND hsr.hostgroup_hg_id = hgr.hostgroup_hg_id '
+            . 'AND h.host_name LIKE :hostName '
+            . 'AND service_id = hsr.service_service_id '
+            . 'AND service_description LIKE :serviceDescription '
+        );
+        $statement->bindValue(':hostName', $hostName, PDO::PARAM_STR);
+        $statement->bindValue(':serviceDescription', $serviceDescription, PDO::PARAM_STR);
+        $statement->execute();
+        if ($row = $statement->fetch()) {
+            return (int) $row['service_id'];
+        }
+        $statement->closeCursor();
+
+        return null;
+    }
+
+    /**
+     * Get service notes url
+     *
+     * @param int $serviceId
+     *
+     * @throws PDOException
+     * @return string|null
+     */
+    private function getServiceNotesUrl(int $serviceId): ?string
+    {
+        $notesUrl = null;
+
+        $statement = $this->DB->prepare(
+            'SELECT esi_notes_url '
+            . 'FROM extended_service_information '
+            . 'WHERE service_service_id = :serviceId'
+        );
+
+        $statement->bindValue(':serviceId', $serviceId, PDO::PARAM_INT);
+        $statement->execute();
+
+        if ($row = $statement->fetch()) {
+            $notesUrl = $row['esi_notes_url'];
+        }
+
+        return $notesUrl;
+    }
 }
