@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2020 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,9 +21,9 @@
 
 namespace ConfigGenerateRemote;
 
+use ConfigGenerateRemote\Abstracts\AbstractObject;
 use Exception;
 use PDO;
-use ConfigGenerateRemote\Abstracts\AbstractObject;
 use PDOStatement;
 
 /**
@@ -36,8 +36,10 @@ class Broker extends AbstractObject
 {
     /** @var PDOStatement|null */
     public $stmtEngine;
+
     /** @var string */
     protected $table = 'cfg_centreonbroker';
+
     /** @var string */
     protected $generateFilename = 'cfg_centreonbroker.infile';
 
@@ -58,6 +60,7 @@ class Broker extends AbstractObject
         daemon,
         pool_size
     ';
+
     /** @var string[] */
     protected $attributesWrite = [
         'config_id',
@@ -75,23 +78,38 @@ class Broker extends AbstractObject
         'daemon',
         'pool_size',
     ];
+
     /** @var PDOStatement|null */
     protected $stmtBroker = null;
 
+    /**
+     * Generate engine configuration from poller
+     *
+     * @param array $poller
+     *
+     * @throws Exception
+     * @return void
+     */
+    public function generateFromPoller(array $poller): void
+    {
+        Resource::getInstance($this->dependencyInjector)->generateFromPollerId($poller['id']);
+        $this->generate($poller['id']);
+    }
+
     /**
      * Generate broker configuration from poller id
      *
      * @param int $pollerId
      *
-     * @return void
      * @throws Exception
+     * @return void
      */
     private function generate(int $pollerId): void
     {
         if (is_null($this->stmtEngine)) {
             $this->stmtBroker = $this->backendInstance->db->prepare(
-                "SELECT $this->attributesSelect FROM cfg_centreonbroker " .
-                "WHERE ns_nagios_server = :poller_id AND config_activate = '1'"
+                "SELECT {$this->attributesSelect} FROM cfg_centreonbroker "
+                . "WHERE ns_nagios_server = :poller_id AND config_activate = '1'"
             );
         }
         $this->stmtBroker->bindParam(':poller_id', $pollerId, PDO::PARAM_INT);
@@ -106,18 +124,4 @@ class Broker extends AbstractObject
             );
         }
     }
-
-    /**
-     * Generate engine configuration from poller
-     *
-     * @param array $poller
-     *
-     * @return void
-     * @throws Exception
-     */
-    public function generateFromPoller(array $poller): void
-    {
-        Resource::getInstance($this->dependencyInjector)->generateFromPollerId($poller['id']);
-        $this->generate($poller['id']);
-    }
 }
