@@ -1,12 +1,13 @@
 <?php
+
 /*
- * Copyright 2005 - 2019 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,9 +21,9 @@
 
 namespace ConfigGenerateRemote;
 
+use ConfigGenerateRemote\Abstracts\AbstractObject;
 use Exception;
 use PDO;
-use ConfigGenerateRemote\Abstracts\AbstractObject;
 use PDOStatement;
 use Pimple\Container;
 
@@ -34,19 +35,12 @@ use Pimple\Container;
  */
 class ServiceGroup extends AbstractObject
 {
-    /** @var int */
-    private $useCache = 1;
-    /** @var int */
-    private $doneCache = 0;
-
-    /** @var array */
-    private $sg = [];
-    /** @var array */
-    private $sgRelationCache = [];
     /** @var string */
     protected $table = 'servicegroup';
+
     /** @var string */
     protected $generateFilename = 'servicegroups.infile';
+
     /** @var string */
     protected $attributesSelect = '
         sg_id,
@@ -54,20 +48,36 @@ class ServiceGroup extends AbstractObject
         sg_alias,
         geo_coords
     ';
+
     /** @var string[] */
     protected $attributesWrite = [
         'sg_id',
         'sg_name',
         'sg_alias',
-        'geo_coords'
+        'geo_coords',
     ];
+
     /** @var PDOStatement */
     protected $stmtSg = null;
+
     /** @var PDOStatement */
     protected $stmtServiceSg = null;
+
     /** @var PDOStatement */
     protected $stmtStplSg = null;
 
+    /** @var int */
+    private $useCache = 1;
+
+    /** @var int */
+    private $doneCache = 0;
+
+    /** @var array */
+    private $sg = [];
+
+    /** @var array */
+    private $sgRelationCache = [];
+
     /**
      * ServiceGroup constructor
      *
@@ -79,32 +89,6 @@ class ServiceGroup extends AbstractObject
         $this->buildCache();
     }
 
-    /**
-     * Get servicegroup frm id
-     *
-     * @param int $sgId
-     * @return void
-     */
-    private function getServicegroupFromId(int $sgId)
-    {
-        if (is_null($this->stmtSg)) {
-            $this->stmtSg = $this->backendInstance->db->prepare(
-                "SELECT $this->attributesSelect
-                FROM servicegroup
-                WHERE sg_id = :sg_id AND sg_activate = '1'"
-            );
-        }
-
-        $this->stmtSg->bindParam(':sg_id', $sgId, PDO::PARAM_INT);
-        $this->stmtSg->execute();
-        $results = $this->stmtSg->fetchAll(PDO::FETCH_ASSOC);
-        $this->sg[$sgId] = array_pop($results);
-        if (is_null($this->sg[$sgId])) {
-            return 1;
-        }
-        $this->sg[$sgId]['members_cache'] = [];
-    }
-
     /**
      * Generate service group
      *
@@ -114,12 +98,12 @@ class ServiceGroup extends AbstractObject
      * @param int $hostId
      * @param string $hostName
      *
-     * @return int
      * @throws Exception
+     * @return int
      */
     public function addServiceInSg(int $sgId, int $serviceId, string $serviceDescription, int $hostId, string $hostName)
     {
-        if (!isset($this->sg[$sgId])) {
+        if (! isset($this->sg[$sgId])) {
             $this->getServicegroupFromId($sgId);
             $this->generateObjectInFile($this->sg[$sgId], $sgId);
         }
@@ -128,36 +112,10 @@ class ServiceGroup extends AbstractObject
         }
 
         $this->sg[$sgId]['members_cache'][$hostId . '_' . $serviceId] = [$hostName, $serviceDescription];
+
         return 0;
     }
 
-    /**
-     * Build cache
-     *
-     * @return void
-     */
-    private function buildCache()
-    {
-        if ($this->doneCache == 1) {
-            return 0;
-        }
-
-        $stmt = $this->backendInstance->db->prepare("SELECT 
-                  service_service_id, servicegroup_sg_id, host_host_id
-                FROM servicegroup_relation
-        ");
-        $stmt->execute();
-        foreach ($stmt->fetchAll(PDO::FETCH_ASSOC) as $value) {
-            if (isset($this->sgRelationCache[$value['service_service_id']])) {
-                $this->sgRelationCache[$value['service_service_id']][] = $value;
-            } else {
-                $this->sgRelationCache[$value['service_service_id']] = [$value];
-            }
-        }
-
-        $this->doneCache = 1;
-    }
-
     /**
      * Get service group from service template id
      *
@@ -177,9 +135,9 @@ class ServiceGroup extends AbstractObject
         if (is_null($this->stmtStplSg)) {
             // Meaning, linked with the host or hostgroup (for the null expression)
             $this->stmtStplSg = $this->backendInstance->db->prepare(
-                "SELECT servicegroup_sg_id, host_host_id, service_service_id
+                'SELECT servicegroup_sg_id, host_host_id, service_service_id
                 FROM servicegroup_relation
-                WHERE service_service_id = :service_id"
+                WHERE service_service_id = :service_id'
             );
         }
         $this->stmtStplSg->bindParam(':service_id', $serviceId, PDO::PARAM_INT);
@@ -188,6 +146,7 @@ class ServiceGroup extends AbstractObject
             $this->stmtStplSg->fetchAll(PDO::FETCH_ASSOC),
             $this->sgRelationCache[$serviceId]
         );
+
         return $this->sgRelationCache[$serviceId];
     }
 
@@ -211,10 +170,10 @@ class ServiceGroup extends AbstractObject
         if (is_null($this->stmtServiceSg)) {
             // Meaning, linked with the host or hostgroup (for the null expression)
             $this->stmtServiceSg = $this->backendInstance->db->prepare(
-                "SELECT servicegroup_sg_id, host_host_id, service_service_id
+                'SELECT servicegroup_sg_id, host_host_id, service_service_id
                 FROM servicegroup_relation
                 WHERE service_service_id = :service_id
-                AND (host_host_id = :host_id OR host_host_id IS NULL)"
+                AND (host_host_id = :host_id OR host_host_id IS NULL)'
             );
         }
         $this->stmtServiceSg->bindParam(':service_id', $serviceId, PDO::PARAM_INT);
@@ -224,6 +183,7 @@ class ServiceGroup extends AbstractObject
             $this->stmtServiceSg->fetchAll(PDO::FETCH_ASSOC),
             $this->sgRelationCache[$serviceId]
         );
+
         return $this->sgRelationCache[$serviceId];
     }
 
@@ -232,8 +192,8 @@ class ServiceGroup extends AbstractObject
      *
      * @param int $sgId
      *
-     * @return void
      * @throws Exception
+     * @return void
      */
     public function generateObject(int $sgId)
     {
@@ -247,8 +207,8 @@ class ServiceGroup extends AbstractObject
     /**
      * Generate objects
      *
-     * @return void
      * @throws Exception
+     * @return void
      */
     public function generateObjects(): void
     {
@@ -276,6 +236,7 @@ class ServiceGroup extends AbstractObject
             }
             $result[$id] = &$value;
         }
+
         return $result;
     }
 
@@ -284,8 +245,8 @@ class ServiceGroup extends AbstractObject
      *
      * @param bool $createfile
      *
-     * @return void
      * @throws Exception
+     * @return void
      */
     public function reset($createfile = false): void
     {
@@ -304,4 +265,57 @@ class ServiceGroup extends AbstractObject
     {
         return $this->sg[$sgId][$attr] ?? null;
     }
+
+    /**
+     * Get servicegroup frm id
+     *
+     * @param int $sgId
+     * @return void
+     */
+    private function getServicegroupFromId(int $sgId)
+    {
+        if (is_null($this->stmtSg)) {
+            $this->stmtSg = $this->backendInstance->db->prepare(
+                "SELECT {$this->attributesSelect}
+                FROM servicegroup
+                WHERE sg_id = :sg_id AND sg_activate = '1'"
+            );
+        }
+
+        $this->stmtSg->bindParam(':sg_id', $sgId, PDO::PARAM_INT);
+        $this->stmtSg->execute();
+        $results = $this->stmtSg->fetchAll(PDO::FETCH_ASSOC);
+        $this->sg[$sgId] = array_pop($results);
+        if (is_null($this->sg[$sgId])) {
+            return 1;
+        }
+        $this->sg[$sgId]['members_cache'] = [];
+    }
+
+    /**
+     * Build cache
+     *
+     * @return void
+     */
+    private function buildCache()
+    {
+        if ($this->doneCache == 1) {
+            return 0;
+        }
+
+        $stmt = $this->backendInstance->db->prepare('SELECT 
+                  service_service_id, servicegroup_sg_id, host_host_id
+                FROM servicegroup_relation
+        ');
+        $stmt->execute();
+        foreach ($stmt->fetchAll(PDO::FETCH_ASSOC) as $value) {
+            if (isset($this->sgRelationCache[$value['service_service_id']])) {
+                $this->sgRelationCache[$value['service_service_id']][] = $value;
+            } else {
+                $this->sgRelationCache[$value['service_service_id']] = [$value];
+            }
+        }
+
+        $this->doneCache = 1;
+    }
 }
