@@ -27,9 +27,9 @@ export const labelSave = 'Save';
 export const labelPortExpectedAtMost = 'Port number must be at most 65535';
 export const labelPortMustStartFrom1 = 'Port number must be at least 1';
 export const labelExtensionNotAllowed = 'Extension not allowed';
-export const labelPublicCertificate = 'Public certificate(.crt,.cer)';
-export const labelCaCertificate = 'CA(.crt,.cer)';
-export const labelPrivateKey = 'Private key(.key)';
+export const labelPublicCertificate = 'Public certificate (.crt, .cert, .cer)';
+export const labelCaCertificate = 'CA (.crt, .cert, .cer)';
+export const labelPrivateKey = 'Private key (.key)';
 export const labelOTLPReceiver = 'OTLP Receiver';
 export const labelAddressInvalid = 'Invalid address';
 export const labelMonitoredHosts = 'Monitored hosts';
