@@ -43,15 +43,18 @@ import {
   labelCertificate,
   labelDefineRelationBetweenRolesAndAclAccessGroups,
   labelEmailAttribute,
+  labelEnableRequestedAuthnContext,
   labelEnableSAMLAuthentication,
   labelEntityIdURL,
   labelFullNameAttribute,
   labelLogoutFrom,
   labelLogoutUrl,
   labelRemoteLoginUrl,
+  labelRequestedAuthnContextComparison,
   labelSAMLOnly,
   labelUserIdAttribute
 } from '../translatedLabels';
+import RequestedAuthnContextComparisonField from './RequestedAuthnContextField';
 
 const isAutoImportDisabled = (values: FormikValues): boolean =>
   not(prop('autoImport', values));
@@ -132,7 +135,8 @@ const rolesMapping: Array<InputProps> = [
         {
           connectedAutocomplete: {
             additionalConditionParameters: [],
-            endpoint: accessGroupsEndpoint
+            endpoint: accessGroupsEndpoint,
+            getOptionLabel: (option) => option.name
           },
           dataTestId: 'saml_accessGroup',
           fieldName: 'accessGroup',
@@ -182,7 +186,8 @@ const groupsMapping: Array<InputProps> = [
         {
           connectedAutocomplete: {
             additionalConditionParameters: [],
-            endpoint: contactGroupsEndpoint
+            endpoint: contactGroupsEndpoint,
+            getOptionLabel: (option) => option.name
           },
           dataTestId: 'saml_contactGroup',
           fieldName: 'contactGroup',
@@ -264,6 +269,25 @@ export const inputs: Array<InputProps> = [
     required: true,
     type: InputType.Text
   },
+  {
+    type: InputType.Switch,
+    dataTestId: 'saml_requestAuthnContext',
+    fieldName: 'requestedAuthnContext',
+    group: labelIdentityProvider,
+    label: labelEnableRequestedAuthnContext
+  },
+  {
+    custom: {
+      Component: RequestedAuthnContextComparisonField
+    },
+    dataTestId: 'saml_requestedAuthnContextComparison',
+    fieldName: 'requestedAuthnContextComparison',
+    group: labelIdentityProvider,
+    hideInput: (values: FormikValues): boolean => !values.requestedAuthnContext,
+    label: labelRequestedAuthnContextComparison,
+    required: true,
+    type: InputType.Custom
+  },
   {
     dataTestId: 'saml_logoutFrom',
     fieldName: 'logoutFrom',
@@ -302,7 +326,8 @@ export const inputs: Array<InputProps> = [
   {
     connectedAutocomplete: {
       additionalConditionParameters: [],
-      endpoint: contactTemplatesEndpoint
+      endpoint: contactTemplatesEndpoint,
+      getOptionLabel: (option) => option.name
     },
     dataTestId: 'saml_contactTemplate',
     fieldName: 'contactTemplate',
