@@ -24,7 +24,8 @@ export interface SAMLConfiguration {
   logoutFrom: boolean;
   logoutFromUrl?: string | null;
   remoteLoginUrl: string;
-  requestedAuthnContext: RequestedAuthnContextValue;
+  requestedAuthnContext: boolean;
+  requestedAuthnContextComparison?: RequestedAuthnContextComparisonValue;
   rolesMapping: SharedRolesMapping;
   userIdAttribute: string;
 }
@@ -43,12 +44,13 @@ export interface SAMLConfigurationToAPI {
   logout_from: boolean;
   logout_from_url: string | null;
   remote_login_url: string;
-  requested_authn_context: string;
+  requested_authn_context_comparison?: string;
+  requested_authn_contexted: boolean;
   roles_mapping: SharedRolesMappingToAPI;
   user_id_attribute: string;
 }
 
-export enum RequestedAuthnContextValue {
+export enum RequestedAuthnContextComparisonValue {
   Minimum = 'minimum',
   Exact = 'exact',
   Better = 'better',
