@@ -1,6 +1,6 @@
-import { keys } from 'ramda';
+import { equals, keys } from 'ramda';
 
-import { getDefaultParameters } from '../utils';
+import { maskedPassword } from '../utils';
 
 import { ParameterKeys } from '../models';
 import initialize from './initialize';
@@ -27,6 +27,13 @@ import {
   labelvCenterESX
 } from '../translatedLabels';
 
+export const defaultParameters = {
+  [ParameterKeys.name]: 'my_vcenter',
+  [ParameterKeys.url]: 'https://<ip_hostname>/sdk',
+  [ParameterKeys.username]: '',
+  [ParameterKeys.password]: ''
+};
+
 const vcenters = [
   {
     [ParameterKeys.name]: 'vCenter1',
@@ -76,10 +83,10 @@ export default (): void => {
       cy.findByText(labelvCenterESX).should('be.visible');
       cy.findAllByTestId('parameterGroup').should('have.length', 1);
 
-      keys(getDefaultParameters(0)).forEach((parameter) => {
+      keys(defaultParameters).forEach((parameter) => {
         cy.get(`input[data-testid="${parameter}_value"`)
           .should('be.visible')
-          .should('have.value', getDefaultParameters(0)[parameter])
+          .should('have.value', defaultParameters[parameter])
           .should('not.be.disabled');
       });
 
@@ -138,11 +145,19 @@ export default (): void => {
 
       vcenters.forEach((vcenter, index) => {
         keys(vcenter).forEach((parameter) => {
-          cy.get(`input[data-testid="${parameter}_value"`)
-            .eq(index)
-            .should('be.visible')
-            .should('have.value', vcenter[parameter])
-            .should('not.be.disabled');
+          if (equals(parameter, 'Password')) {
+            cy.get(`input[data-testid="${parameter}_value"`)
+              .eq(index)
+              .should('be.visible')
+              .should('have.value', maskedPassword)
+              .should('be.disabled');
+          } else {
+            cy.get(`input[data-testid="${parameter}_value"`)
+              .eq(index)
+              .should('be.visible')
+              .should('have.value', vcenter[parameter])
+              .should('not.be.disabled');
+          }
         });
       });
 
@@ -391,7 +406,7 @@ export default (): void => {
         cy.findByLabelText('close').click();
       });
 
-      it('validates that vCenter username is not required Edition Mode', () => {
+      it('validates that vCenter username is required Edition Mode', () => {
         cy.waitForRequest('@getConnectors');
 
         cy.contains('VMWare1').click();
@@ -400,12 +415,12 @@ export default (): void => {
 
         clickOutideTheField();
 
-        cy.contains(labelRequired).should('not.exist');
+        cy.contains(labelRequired).should('be.visible');
 
         cy.matchImageSnapshot();
 
         cy.findByLabelText('close').click();
-        cy.findByLabelText('Discard').click();
+        cy.findByLabelText('Leave').click();
       });
 
       it('validates that vCenter password field is required in Creation Mode', () => {
@@ -423,12 +438,17 @@ export default (): void => {
         cy.findByLabelText('close').click();
       });
 
-      it('validates that vCenter password field is not required in Edition Mode', () => {
+      it('validates that vCenter password field is disabled and masked in Edition Mode', () => {
         cy.waitForRequest('@getConnectors');
 
         cy.contains('VMWare1').click();
 
-        cy.get(`input[data-testid="Password_value"`).clear();
+        cy.get(`input[data-testid="Password_value"`).should('be.disabled');
+
+        cy.get(`input[data-testid="Password_value"`).should(
+          'have.value',
+          maskedPassword
+        );
 
         clickOutideTheField();
 
@@ -437,7 +457,6 @@ export default (): void => {
         cy.matchImageSnapshot();
 
         cy.findByLabelText('close').click();
-        cy.findByLabelText('Discard').click();
       });
 
       it('validates that port field is required', () => {
@@ -609,6 +628,14 @@ export default (): void => {
         cy.findAllByTestId(labelName).eq(1).clear().type('Updated name');
         cy.get('input[name=port]').clear().type('100');
 
+        cy.get(`input[data-testid="Password_value"`)
+          .eq(0)
+          .should('be.disabled');
+        cy.findAllByTestId('EditIcon').eq(0).click();
+        cy.get(`input[data-testid="Password_value"`).eq(0).type('new password');
+        cy.findByTestId('CheckIcon').click();
+        cy.findByTestId('RestartAltIcon').should('be.visible');
+
         cy.get(`button[data-testid="submit"`).click();
 
         cy.waitForRequest('@updateConnector').then(({ request }) => {
@@ -620,14 +647,14 @@ export default (): void => {
               vcenters: [
                 {
                   name: 'vCenter1',
-                  password: 'password1',
+                  password: 'new password',
                   url: 'vcenter1.example.com/sdk',
                   username: 'user1',
                   scheme: 'https'
                 },
                 {
                   name: 'vCenter2',
-                  password: 'password2',
+                  password: null,
                   url: '192.0.0.1',
                   username: 'user2',
                   scheme: null
