@@ -1,7 +1,7 @@
 import i18next from 'i18next';
 import { Provider, createStore } from 'jotai';
 import { initReactI18next } from 'react-i18next';
-import { BrowserRouter } from 'react-router-dom';
+import { BrowserRouter } from 'react-router';
 
 import { Method } from '@centreon/js-config/cypress/component/commands';
 import { SnackbarProvider, TestQueryProvider } from '@centreon/ui';
@@ -14,16 +14,20 @@ import {
 
 import { labelMoreActions } from '../Resources/translatedLabels';
 
+import { equals } from 'ramda';
 import { DashboardsPage } from './DashboardsPage';
 import {
   dashboardSharesEndpoint,
   dashboardsContactsEndpoint,
   dashboardsEndpoint,
+  dashboardsFavoriteEndpoint,
   getDashboardAccessRightsContactGroupEndpoint,
   getDashboardEndpoint,
   playlistsByDashboardEndpoint
 } from './api/endpoints';
 import { DashboardRole } from './api/models';
+import { viewModeAtom } from './components/DashboardLibrary/DashboardListing/atom';
+import { ViewMode } from './components/DashboardLibrary/DashboardListing/models';
 import {
   labelCardsView,
   labelEditProperties,
@@ -31,8 +35,12 @@ import {
   labelListView,
   labelViewer
 } from './components/DashboardLibrary/DashboardListing/translatedLabels';
-import { DashboardLayout } from './models';
+import { DashboardLayout, FavoriteAction, GetPath } from './models';
 import { routerHooks } from './routerHooks';
+import {
+  interceptDashboardsFavoriteDelete,
+  manageAFavorite
+} from './testsUtils';
 import {
   labelAddAContact,
   labelCancel,
@@ -48,6 +56,7 @@ import {
   labelDuplicateDashboard,
   labelName,
   labelSave,
+  labelSaveYourDashboardForThumbnail,
   labelShareWithContacts,
   labelSharesSaved,
   labelUpdate,
@@ -63,6 +72,7 @@ interface InitializeAndMountProps {
   globalRole?: DashboardGlobalRole;
   layout?: DashboardLayout;
   ownRole?: DashboardRole;
+  customListingPath?: string;
 }
 
 const initializeAndMount = ({
@@ -71,13 +81,16 @@ const initializeAndMount = ({
   canViewDashboard = true,
   canAdministrateDashboard = true,
   emptyList,
-  layout = DashboardLayout.Library
+  layout = DashboardLayout.Library,
+  customListingPath
 }: InitializeAndMountProps): {
   navigate;
   store;
 } => {
   const store = createStore();
 
+  store.set(viewModeAtom, ViewMode.List);
+
   store.set(userAtom, {
     alias: 'admin',
     dashboard: {
@@ -102,7 +115,8 @@ const initializeAndMount = ({
   cy.viewport('macbook-13');
 
   cy.fixture(
-    `Dashboards/${emptyList ? 'emptyDashboards' : 'dashboards'}.json`
+    customListingPath ??
+      `Dashboards/${emptyList ? 'emptyDashboards' : 'dashboards'}.json`
   ).then((dashboards) => {
     cy.interceptAPIRequest({
       alias: 'getDashboards',
@@ -162,7 +176,7 @@ const initializeAndMount = ({
 
   cy.interceptAPIRequest({
     alias: 'updateDashboard',
-    method: Method.PATCH,
+    method: Method.POST,
     path: `${dashboardsEndpoint}/1`,
     statusCode: 204
   });
@@ -179,6 +193,24 @@ const initializeAndMount = ({
     path: getDashboardAccessRightsContactGroupEndpoint(1, 3)
   });
 
+  cy.interceptAPIRequest({
+    alias: 'addFavorite',
+    method: Method.POST,
+    path: `./api/latest${dashboardsFavoriteEndpoint}`,
+    statusCode: 204
+  });
+
+  cy.fixture('Dashboards/favorites/listing/listAllMarkedFavorite.json').then(
+    (data) => {
+      cy.interceptAPIRequest({
+        alias: 'getFavoritesList',
+        method: Method.GET,
+        path: `./api/latest${dashboardsFavoriteEndpoint}?**`,
+        response: data
+      });
+    }
+  );
+
   const version = {
     fix: '0',
     major: '0',
@@ -255,6 +287,75 @@ const columns = [
   'Actions'
 ];
 
+const favoriteManagementData = [
+  { view: labelCardsView, dashboardId: 1 },
+  { view: labelListView, dashboardId: 2 }
+];
+
+const getAliasFavoriteButton = (position: number) => {
+  cy.findAllByRole('button', { name: 'FavoriteIconButton' }).as('listButtons');
+
+  if (equals(position, 0)) {
+    cy.get('@listButtons').first().as('favoriteIcon');
+
+    return '@favoriteIcon';
+  }
+
+  cy.get('@listButtons').last().as('favoriteIcon');
+
+  return '@favoriteIcon';
+};
+
+const getPath = ({ position, action }: GetPath) => {
+  if (equals(position, 0)) {
+    const path = equals(action, FavoriteAction.add)
+      ? 'Dashboards/favorites/listing/afterAddAction/listOne.json'
+      : 'Dashboards/favorites/listing/afterDeleteAction/listOne.json';
+
+    return path;
+  }
+
+  const path = equals(action, FavoriteAction.add)
+    ? 'Dashboards/favorites/listing/afterAddAction/listTwo.json'
+    : 'Dashboards/favorites/listing/afterDeleteAction/listTwo.json';
+
+  return path;
+};
+
+const runFavoriteManagementFromList = ({
+  action,
+  position,
+  view,
+  customListingPath
+}) => {
+  initializeAndMount({ customListingPath });
+  cy.waitForRequest('@getDashboards');
+
+  const buttonAlias = getAliasFavoriteButton(position);
+  const path = getPath({ position, action });
+
+  const aliasRequestAction = equals(FavoriteAction.add, action)
+    ? '@addFavorite'
+    : '@removeFavorite';
+
+  cy.fixture(path).then((dashboards) => {
+    cy.interceptAPIRequest({
+      alias: 'getUpdatedDashboards',
+      method: Method.GET,
+      path: `${dashboardsEndpoint}?**`,
+      response: dashboards
+    });
+  });
+
+  cy.findByRole('button', { name: view }).click();
+
+  manageAFavorite({
+    action,
+    buttonAlias,
+    requestsToWait: [aliasRequestAction, '@getUpdatedDashboards']
+  });
+};
+
 describe('Dashboards', () => {
   describe('Overview', () => {
     it('displays a welcome label when the dashboard library is empty', () => {
@@ -327,7 +428,17 @@ describe('Dashboards', () => {
       );
 
       cy.contains('My Dashboard').should('be.visible');
+      cy.findByTestId('thumbnail-My Dashboard-my description').should(
+        'be.visible'
+      );
       cy.contains('My Dashboard 2').should('be.visible');
+      cy.findByTestId('thumbnail-My Dashboard 2-undefined').should(
+        'be.visible'
+      );
+
+      cy.findAllByTestId('thumbnail-fallback').first().trigger('mouseover');
+
+      cy.contains(labelSaveYourDashboardForThumbnail).should('be.visible');
 
       cy.makeSnapshot();
     });
@@ -533,7 +644,7 @@ describe('Dashboards', () => {
         cy.findByLabelText(labelDuplicate).click();
 
         cy.waitForRequest('@createDashboard').then(({ request }) => {
-          expect(JSON.parse(request.body).name).to.be.equal('new name');
+          expect(request.body.name).to.be.equal('new name');
         });
 
         cy.contains(labelDashboardDuplicated).should('be.visible');
@@ -605,7 +716,14 @@ describe('Dashboards', () => {
         cy.findByLabelText(labelUpdate).click();
 
         cy.waitForRequest('@updateDashboard').then(({ request }) => {
-          expect(JSON.parse(request.body)).to.deep.equal({
+          const formData = new URLSearchParams(request.body);
+
+          const formDataObj = {};
+          formData.forEach((value, key) => {
+            formDataObj[key] = value;
+          });
+
+          expect(formDataObj).to.deep.equal({
             description: 'New description',
             name: 'New name'
           });
@@ -812,4 +930,43 @@ describe('Dashboards', () => {
       cy.makeSnapshot();
     });
   });
+
+  describe('Managment favorite dashboards', () => {
+    favoriteManagementData.forEach(({ view, dashboardId }, index) => {
+      it(`add a dashboard to favorites when clicking on the corresponding icon in the ${view}`, () => {
+        runFavoriteManagementFromList({
+          position: index,
+          view,
+          action: FavoriteAction.add,
+          customListingPath: 'Dashboards/favorites/listing/list.json'
+        });
+        cy.makeSnapshot();
+      });
+
+      it(`remove a dashboard to favorites when clicking on the corresponding icon in the ${view}`, () => {
+        interceptDashboardsFavoriteDelete(dashboardId);
+
+        runFavoriteManagementFromList({
+          position: index,
+          view,
+          action: FavoriteAction.delete,
+          customListingPath:
+            'Dashboards/favorites/listing/listAllMarkedFavorite.json'
+        });
+        cy.makeSnapshot();
+      });
+    });
+
+    it('displays the favorites dashboard when the checkbox filter is selected.', () => {
+      initializeAndMount({});
+      cy.waitForRequest('@getDashboards');
+
+      cy.get('[type="checkbox"]').check();
+      cy.waitForRequest('@getFavoritesList');
+      cy.makeSnapshot();
+
+      cy.get('[type="checkbox"]').uncheck();
+      cy.waitForRequest('@getDashboards');
+    });
+  });
 });
