@@ -2,14 +2,14 @@ import { JsonDecoder } from 'ts.data.json';
 
 import { buildListingDecoder } from '@centreon/ui';
 
-import { resourceDecoder } from '../../../../decoders';
+import { metricsResourceDecoder } from '../../../../decoders';
 import { MetaServiceMetric } from '../models';
 
 const metaServiceMetricDecoder = JsonDecoder.object<MetaServiceMetric>(
   {
     id: JsonDecoder.number,
     name: JsonDecoder.string,
-    resource: resourceDecoder,
+    resource: metricsResourceDecoder,
     unit: JsonDecoder.string,
     value: JsonDecoder.number
   },
