@@ -8,6 +8,7 @@ import type { ComponentColumnProps } from '@centreon/ui';
 
 import { labelNotificationDisabled } from '../../translatedLabels';
 
+import { equals } from 'ramda';
 import IconColumn from './IconColumn';
 
 const useStyles = makeStyles()((theme) => ({
@@ -36,7 +37,7 @@ const NotificationColumn = ({
   const { classes } = useStyles();
   const { t } = useTranslation();
 
-  if (row.notification_enabled === false) {
+  if (equals(row.is_notification_enabled, false)) {
     return (
       <IconColumn>
         <div className={classes.container}>
