@@ -19,6 +19,10 @@
  *
  */
 
+use Adaptation\Database\Connection\Collection\QueryParameters;
+use Adaptation\Database\Connection\Enum\QueryParameterTypeEnum;
+use Adaptation\Database\Connection\ValueObject\QueryParameter;
+
 require_once '../../require.php';
 require_once $centreon_path . 'bootstrap.php';
 require_once $centreon_path . 'www/class/centreon.class.php';
@@ -26,19 +30,23 @@ require_once $centreon_path . 'www/class/centreonSession.class.php';
 require_once $centreon_path . 'www/class/centreonWidget.class.php';
 require_once $centreon_path . 'www/class/centreonDuration.class.php';
 require_once $centreon_path . 'www/class/centreonUtils.class.php';
-require_once $centreon_path . 'www/class/centreonACL.class.php';
 require_once $centreon_path . 'www/class/centreonHost.class.php';
 require_once $centreon_path . 'www/class/centreonService.class.php';
 require_once $centreon_path . 'www/class/centreonMedia.class.php';
 require_once $centreon_path . 'www/class/centreonCriticality.class.php';
+require_once $centreon_path . 'www/class/centreonAclLazy.class.php';
+require_once $centreon_path . 'www/include/common/sqlCommonFunction.php';
 
 CentreonSession::start(1);
 if (! isset($_SESSION['centreon']) || ! isset($_REQUEST['widgetId']) || ! isset($_REQUEST['page'])) {
     exit;
 }
 
-$db = $dependencyInjector['configuration_db'];
-if (CentreonSession::checkSession(session_id(), $db) == 0) {
+/**
+ * @var CentreonDB $configurationDatabase
+ */
+$configurationDatabase = $dependencyInjector['configuration_db'];
+if (CentreonSession::checkSession(session_id(), $configurationDatabase) == 0) {
     exit();
 }
 
@@ -46,8 +54,8 @@ if (CentreonSession::checkSession(session_id(), $db) == 0) {
 $template = SmartyBC::createSmartyTemplate($centreon_path . 'www/widgets/service-monitoring/src/', './');
 
 // Init Objects
-$criticality = new CentreonCriticality($db);
-$media = new CentreonMedia($db);
+$criticality = new CentreonCriticality($configurationDatabase);
+$media = new CentreonMedia($configurationDatabase);
 
 $centreon = $_SESSION['centreon'];
 
@@ -57,16 +65,75 @@ $centreon = $_SESSION['centreon'];
  */
 $useDeprecatedPages = $centreon->user->doesShowDeprecatedPages();
 
-$widgetId = filter_input(INPUT_GET, 'widgetId', FILTER_VALIDATE_INT, ['options' => ['default' => 0]]);
-$page = filter_input(INPUT_GET, 'page', FILTER_VALIDATE_INT, ['options' => ['default' => 0]]);
+$widgetId = filter_input(
+    INPUT_GET,
+    'widgetId',
+    FILTER_VALIDATE_INT,
+    ['options' => ['default' => 0]],
+);
+
+$page = filter_input(
+    INPUT_GET,
+    'page',
+    FILTER_VALIDATE_INT,
+    ['options' => ['default' => 0]],
+);
 
 /**
- * @var CentreonDB $dbb
+ * @var CentreonDB $realtimeDatabase
+ */
+$realtimeDatabase = $dependencyInjector['realtime_db'];
+$widgetObj = new CentreonWidget($centreon, $configurationDatabase);
+
+/**
+ * @var array{
+ *     host_name_search: string,
+ *     service_description_search: string,
+ *     svc_ok: string,
+ *     hide_down_host: string,
+ *     hide_unreachable_host: string,
+ *     svc_warning: string,
+ *     svc_critical: string,
+ *     svc_unknown: string,
+ *     svc_pending: string,
+ *     criticality_filter: string,
+ *     acknowledgement_filter: string,
+ *     notification_filter: string,
+ *     downtime_filter: string,
+ *     state_type_filter: string,
+ *     poller: string,
+ *     hostgroup: string,
+ *     servicegroup: string,
+ *     entries: string,
+ *     output_search: string,
+ *     display_severities: string,
+ *     display_host_name: string,
+ *     display_host_alias: string,
+ *     display_chart_icon: string,
+ *     display_svc_description: string,
+ *     display_output: string,
+ *     output_length: string,
+ *     display_status: string,
+ *     display_last_check: string,
+ *     display_duration: string,
+ *     display_hard_state_duration: string,
+ *     display_tries: string,
+ *     display_last_comment: string,
+ *     display_latency: string,
+ *     display_execution_time: string,
+ *     comment_length: string,
+ *     order_by: string,
+ *     order_by2: string,
+ *     refresh_interval: string,
+ *     more_views: string
+ * } $preferences
  */
-$dbb = $dependencyInjector['realtime_db'];
-$widgetObj = new CentreonWidget($centreon, $db);
 $preferences = $widgetObj->getWidgetPreferences($widgetId);
 
+$autoRefresh = (isset($preferences['refresh_interval']) && (int) $preferences['refresh_interval'] > 0)
+    ? (int) $preferences['refresh_interval']
+    : 30;
+
 $stateSColors = [
     0 => '#88b917',
     1 => '#ff9a13',
@@ -88,73 +155,102 @@ $stateLabels = [
     3 => 'Unknown',
     4 => 'Pending',
 ];
-$aStateType = ['1' => 'H', '0' => 'S'];
+
+$aStateType = [
+    '1' => 'H',
+    '0' => 'S',
+];
+
 $mainQueryParameters = [];
 
-// Build Query
-$query = 'SELECT SQL_CALC_FOUND_ROWS DISTINCT
-    1 AS REALTIME,
-    h.host_id,
-    h.name as hostname,
-    h.alias as hostalias,
-    s.latency,
-    s.execution_time,
-    h.state as h_state,
-    s.service_id,
-    s.description,
-    s.state as s_state,
-    s.state_type as state_type,
-    s.last_hard_state,
-    s.output,
-    s.scheduled_downtime_depth as s_scheduled_downtime_depth,
-    s.acknowledged as s_acknowledged,
-    s.notify as s_notify,
-    s.perfdata,
-    s.active_checks as s_active_checks,
-    s.passive_checks as s_passive_checks,
-    h.scheduled_downtime_depth as h_scheduled_downtime_depth,
-    h.acknowledged as h_acknowledged,
-    h.notify as h_notify,
-    h.active_checks as h_active_checks,
-    h.passive_checks as h_passive_checks,
-    s.last_check,
-    s.last_state_change,
-    s.last_hard_state_change,
-    s.check_attempt,
-    s.max_check_attempts,
-    h.action_url as h_action_url,
-    h.notes_url as h_notes_url,
-    s.action_url as s_action_url,
-    s.notes_url as s_notes_url,
-    cv2.value AS criticality_id,
-    cv.value AS criticality_level,
-    h.icon_image
-    FROM hosts h JOIN instances i ON h.instance_id=i.instance_id, services s
-    LEFT JOIN customvariables cv ON (
-        s.service_id = cv.service_id
-        AND s.host_id = cv.host_id
-        AND cv.name = \'CRITICALITY_LEVEL\'
-    )
-    LEFT JOIN customvariables cv2 ON (
-        s.service_id = cv2.service_id
-        AND s.host_id = cv2.host_id
-        AND cv2.name = \'CRITICALITY_ID\'
-    )';
+$querySelect = <<<'SQL'
+            SELECT DISTINCT
+                1 AS REALTIME,
+                h.host_id,
+                h.name AS hostname,
+                h.alias AS hostalias,
+                s.latency,
+                s.execution_time,
+                h.state AS h_state,
+                s.service_id,
+                s.description,
+                s.state AS s_state,
+                s.state_type AS state_type,
+                s.last_hard_state,
+                s.output,
+                s.scheduled_downtime_depth AS s_scheduled_downtime_depth,
+                s.acknowledged AS s_acknowledged,
+                s.notify AS s_notify,
+                s.perfdata,
+                s.active_checks AS s_active_checks,
+                s.passive_checks AS s_passive_checks,
+                h.scheduled_downtime_depth AS h_scheduled_downtime_depth,
+                h.acknowledged AS h_acknowledged,
+                h.notify AS h_notify,
+                h.active_checks AS h_active_checks,
+                h.passive_checks AS h_passive_checks,
+                s.last_check,
+                s.last_state_change,
+                s.last_hard_state_change,
+                s.check_attempt,
+                s.max_check_attempts,
+                h.action_url AS h_action_url,
+                h.notes_url AS h_notes_url,
+                s.action_url AS s_action_url,
+                s.notes_url AS s_notes_url,
+                cv2.value AS criticality_id,
+                cv.value AS criticality_level,
+                h.icon_image
+    SQL;
 
-if (isset($preferences['acknowledgement_filter']) &&  $preferences['acknowledgement_filter'] == 'ackByMe') {
-    $query .= ' JOIN acknowledgements ack ON (
-        s.service_id = ack.service_id
-    )';
+$baseQuery = <<<'SQL'
+        FROM hosts h
+        INNER JOIN instances i
+            ON h.instance_id = i.instance_id
+        INNER JOIN services s
+            ON s.host_id = h.host_id
+        LEFT JOIN customvariables cv
+            ON s.service_id = cv.service_id
+            AND s.host_id = cv.host_id
+            AND cv.name = 'CRITICALITY_LEVEL'
+        LEFT JOIN customvariables cv2
+            ON s.service_id = cv2.service_id
+            AND s.host_id = cv2.host_id
+            AND cv2.name = 'CRITICALITY_ID'
+    SQL;
+
+if (! empty($preferences['acknowledgement_filter']) &&  $preferences['acknowledgement_filter'] == 'ackByMe') {
+    $baseQuery .= <<<'SQL'
+            INNER JOIN acknowledgements ack
+                ON s.service_id = ack.service_id
+        SQL;
 }
 
 if (! $centreon->user->admin) {
-    $query .= ' , centreon_acl acl ';
+    $acls = new CentreonAclLazy($centreon->user->user_id);
+    $accessGroups = $acls->getAccessGroups()->getIds();
+
+    ['parameters' => $accessGroupParameters, 'placeholderList' => $accessGroupList] = createMultipleBindParameters(
+        $accessGroups,
+        'access_group',
+        QueryParameterTypeEnum::INTEGER
+    );
+
+    $baseQuery .= <<<SQL
+            INNER JOIN centreon_acl acl
+                ON h.host_id = acl.host_id
+                AND s.service_id = acl.service_id
+                AND acl.group_id IN ({$accessGroupList})
+        SQL;
+
+    $mainQueryParameters = [...$accessGroupParameters, ...$mainQueryParameters];
 }
 
-$query .= ' WHERE s.host_id = h.host_id
-    AND h.name NOT LIKE \'_Module_%\'
-    AND s.enabled = 1
-    AND h.enabled = 1 ';
+$baseQuery .= <<<'SQL'
+        WHERE h.name NOT LIKE '_Module_%'
+          AND s.enabled = 1
+          AND h.enabled = 1
+    SQL;
 
 if (isset($preferences['host_name_search']) && $preferences['host_name_search'] != '') {
     $tab = explode(' ', $preferences['host_name_search']);
@@ -163,13 +259,9 @@ if (isset($preferences['host_name_search']) && $preferences['host_name_search']
         $search = $tab[1];
     }
     if ($op && isset($search) && $search != '') {
-        $mainQueryParameters[] = [
-            'parameter' => ':host_name_search',
-            'value' => $search,
-            'type' => PDO::PARAM_STR,
-        ];
+        $mainQueryParameters[] = QueryParameter::string('host_name_search', $search);
         $hostNameCondition = 'h.name ' . CentreonUtils::operandToMysqlFormat($op) . ' :host_name_search ';
-        $query = CentreonUtils::conditionBuilder($query, $hostNameCondition);
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, $hostNameCondition);
     }
 }
 if (isset($preferences['service_description_search']) && $preferences['service_description_search'] != '') {
@@ -179,14 +271,11 @@ if (isset($preferences['service_description_search']) && $preferences['service_d
         $search = $tab[1];
     }
     if ($op && isset($search) && $search != '') {
-        $mainQueryParameters[] = [
-            'parameter' => ':service_description',
-            'value' => $search,
-            'type' => PDO::PARAM_STR,
-        ];
+        $mainQueryParameters[] = QueryParameter::string('service_description', $search);
+
         $serviceDescriptionCondition = 's.description '
             . CentreonUtils::operandToMysqlFormat($op) . ' :service_description ';
-        $query = CentreonUtils::conditionBuilder($query, $serviceDescriptionCondition);
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, $serviceDescriptionCondition);
     }
 }
 $stateTab = [];
@@ -207,24 +296,24 @@ if (isset($preferences['svc_pending']) && $preferences['svc_pending']) {
 }
 
 if (isset($preferences['hide_down_host']) && $preferences['hide_down_host']) {
-    $query = CentreonUtils::conditionBuilder($query, ' h.state != 1 ');
+    $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' h.state != 1 ');
 }
 if (isset($preferences['hide_unreachable_host']) && $preferences['hide_unreachable_host']) {
-    $query = CentreonUtils::conditionBuilder($query, ' h.state != 2 ');
+    $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' h.state != 2 ');
 }
 
 if ($stateTab !== []) {
-    $query = CentreonUtils::conditionBuilder($query, ' s.state IN (' . implode(',', $stateTab) . ')');
+    $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' s.state IN (' . implode(',', $stateTab) . ')');
 }
 if (isset($preferences['acknowledgement_filter']) && $preferences['acknowledgement_filter']) {
     if ($preferences['acknowledgement_filter'] == 'ack') {
-        $query = CentreonUtils::conditionBuilder($query, ' s.acknowledged = 1');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' s.acknowledged = 1');
     } elseif ($preferences['acknowledgement_filter'] == 'ackByMe') {
-        $query = CentreonUtils::conditionBuilder($query, ' s.acknowledged = 1 AND ack.author = "'
-            . $centreon->user->alias . '"');
+        $mainQueryParameters[] = QueryParameter::string('ack_author', $centreon->user->alias);
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' s.acknowledged = 1 AND ack.author = :ack_author');
     } elseif ($preferences['acknowledgement_filter'] == 'nack') {
-        $query = CentreonUtils::conditionBuilder(
-            $query,
+        $baseQuery = CentreonUtils::conditionBuilder(
+            $baseQuery,
             ' s.acknowledged = 0 AND h.acknowledged = 0 AND h.scheduled_downtime_depth = 0 '
         );
     }
@@ -232,36 +321,32 @@ if (isset($preferences['acknowledgement_filter']) && $preferences['acknowledgeme
 
 if (isset($preferences['notification_filter']) && $preferences['notification_filter']) {
     if ($preferences['notification_filter'] == 'enabled') {
-        $query = CentreonUtils::conditionBuilder($query, ' s.notify = 1');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' s.notify = 1');
     } elseif ($preferences['notification_filter'] == 'disabled') {
-        $query = CentreonUtils::conditionBuilder($query, ' s.notify = 0');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' s.notify = 0');
     }
 }
 
 if (isset($preferences['downtime_filter']) && $preferences['downtime_filter']) {
     if ($preferences['downtime_filter'] == 'downtime') {
-        $query = CentreonUtils::conditionBuilder($query, ' s.scheduled_downtime_depth > 0 ');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' s.scheduled_downtime_depth > 0 ');
     } elseif ($preferences['downtime_filter'] == 'ndowntime') {
-        $query = CentreonUtils::conditionBuilder($query, ' s.scheduled_downtime_depth = 0 ');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' s.scheduled_downtime_depth = 0 ');
     }
 }
 
 if (isset($preferences['state_type_filter']) && $preferences['state_type_filter']) {
     if ($preferences['state_type_filter'] == 'hardonly') {
-        $query = CentreonUtils::conditionBuilder($query, ' s.state_type = 1 ');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' s.state_type = 1 ');
     } elseif ($preferences['state_type_filter'] == 'softonly') {
-        $query = CentreonUtils::conditionBuilder($query, ' s.state_type = 0 ');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' s.state_type = 0 ');
     }
 }
 
 if (isset($preferences['poller']) && $preferences['poller']) {
-    $mainQueryParameters[] = [
-        'parameter' => ':instance_id',
-        'value' => $preferences['poller'],
-        'type' => PDO::PARAM_INT,
-    ];
+    $mainQueryParameters[] = QueryParameter::int('instance_id', $preferences['poller']);
     $instanceIdCondition = ' i.instance_id = :instance_id';
-    $query = CentreonUtils::conditionBuilder($query, $instanceIdCondition);
+    $baseQuery = CentreonUtils::conditionBuilder($baseQuery, $instanceIdCondition);
 }
 
 if (isset($preferences['hostgroup']) && $preferences['hostgroup']) {
@@ -272,14 +357,10 @@ if (isset($preferences['hostgroup']) && $preferences['hostgroup']) {
             $queryHG .= ', ';
         }
         $queryHG .= ':id_' . $result;
-        $mainQueryParameters[] = [
-            'parameter' => ':id_' . $result,
-            'value' => (int) $result,
-            'type' => PDO::PARAM_INT,
-        ];
+        $mainQueryParameters[] = QueryParameter::int('id_' . $result, (int) $result);
     }
-    $query = CentreonUtils::conditionBuilder(
-        $query,
+    $baseQuery = CentreonUtils::conditionBuilder(
+        $baseQuery,
         ' s.host_id IN (
             SELECT host_host_id
             FROM `' . $conf_centreon['db'] . '`.hostgroup_relation
@@ -295,14 +376,10 @@ if (isset($preferences['servicegroup']) && $preferences['servicegroup']) {
             $querySG .= ', ';
         }
         $querySG .= ':id_' . $resultSG;
-        $mainQueryParameters[] = [
-            'parameter' => ':id_' . $resultSG,
-            'value' => (int) $resultSG,
-            'type' => PDO::PARAM_INT,
-        ];
+        $mainQueryParameters[] = QueryParameter::int('id_' . $resultSG, (int) $resultSG);
     }
-    $query = CentreonUtils::conditionBuilder(
-        $query,
+    $baseQuery = CentreonUtils::conditionBuilder(
+        $baseQuery,
         ' s.service_id IN (
             SELECT DISTINCT service_id
             FROM services_servicegroups
@@ -315,14 +392,10 @@ if (! empty($preferences['criticality_filter'])) {
     $labels = [];
     foreach ($tab as $p) {
         $labels[] = ':id_' . $p;
-        $mainQueryParameters[] = [
-            'parameter' => ':id_' . $p,
-            'value' => (int) $p,
-            'type' => PDO::PARAM_INT,
-        ];
+        $mainQueryParameters[] = QueryParameter::int('id_' . $p, (int) $p);
     }
-    $query = CentreonUtils::conditionBuilder(
-        $query,
+    $baseQuery = CentreonUtils::conditionBuilder(
+        $baseQuery,
         'cv2.value IN (' . implode(',', $labels) . ')'
     );
 }
@@ -333,22 +406,12 @@ if (isset($preferences['output_search']) && $preferences['output_search'] != '')
         $search = $tab[1];
     }
     if ($op && isset($search) && $search != '') {
-        $mainQueryParameters[] = [
-            'parameter' => ':service_output',
-            'value' => $search,
-            'type' => PDO::PARAM_STR,
-        ];
+        $mainQueryParameters[] = QueryParameter::string('service_output', $search);
         $serviceOutputCondition = 's.output ' . CentreonUtils::operandToMysqlFormat($op) . ' :service_output ';
-        $query = CentreonUtils::conditionBuilder($query, $serviceOutputCondition);
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, $serviceOutputCondition);
     }
 }
-if (! $centreon->user->admin) {
-    $aclObj = new CentreonACL($centreon->user->user_id, $centreon->user->admin);
-    $groupList = $aclObj->getAccessGroupsString();
-    $query .= ' AND h.host_id = acl.host_id
-        AND acl.service_id = s.service_id
-        AND acl.group_id IN (' . $groupList . ') ';
-}
+
 $orderByClause = 'hostname ASC ';
 
 // Define allowed columns and directions
@@ -391,6 +454,9 @@ $allowedOrderColumns = [
 ];
 $allowedDirections = ['ASC', 'DESC'];
 
+$countQuery = 'SELECT COUNT(*) ' . $baseQuery;
+$nbRows = (int) $realtimeDatabase->fetchOne($countQuery, QueryParameters::create($mainQueryParameters));
+
 if (isset($preferences['order_by']) && trim($preferences['order_by']) != '') {
     $aOrder = explode(' ', trim($preferences['order_by']));
     $column = $aOrder[0] ?? '';
@@ -414,28 +480,20 @@ if (isset($preferences['order_by']) && trim($preferences['order_by']) != '') {
 }
 
 if (trim($orderByClause)) {
-    $query .= 'ORDER BY ' . $orderByClause;
+    $baseQuery .= 'ORDER BY ' . $orderByClause;
 }
 
 $num = filter_var($preferences['entries'], FILTER_VALIDATE_INT) ?: 10;
-$query .= ' LIMIT ' . ($page * $num) . ',' . $num;
+$baseQuery .= ' LIMIT ' . ($page * $num) . ',' . $num;
 
-$res = $dbb->prepare($query);
+$records = $realtimeDatabase->fetchAllAssociative($querySelect . $baseQuery, QueryParameters::create($mainQueryParameters));
 
-foreach ($mainQueryParameters as $parameter) {
-    $res->bindValue($parameter['parameter'], $parameter['value'], $parameter['type']);
-}
-
-unset($parameter, $mainQueryParameters);
-$res->execute();
-
-$nbRows = (int) $dbb->query('SELECT FOUND_ROWS() AS REALTIME')->fetchColumn();
 $data = [];
 $outputLength = $preferences['output_length'] ?: 50;
 $commentLength = $preferences['comment_length'] ?: 50;
 
-$hostObj = new CentreonHost($db);
-$svcObj = new CentreonService($db);
+$hostObj = new CentreonHost($configurationDatabase);
+$svcObj = new CentreonService($configurationDatabase);
 $gmt = new CentreonGMT();
 $gmt->getMyGMTFromSession(session_id());
 $allowedActionProtocols = ['http[s]?', '//', 'ssh', 'rdp', 'ftp', 'sftp'];
@@ -444,15 +502,15 @@ $allowedProtocolsRegex = '#(^' . implode(
     $allowedActionProtocols
 ) . ')#'; // String starting with one of these protocols
 
-while ($row = $res->fetch()) {
-    foreach ($row as $key => $value) {
-        $data[$row['host_id'] . '_' . $row['service_id']][$key] = $value;
+foreach ($records as $record) {
+    foreach ($record as $key => $value) {
+        $data[$record['host_id'] . '_' . $record['service_id']][$key] = $value;
     }
 
-    $dataKey = $row['host_id'] . '_' . $row['service_id'];
+    $dataKey = $record['host_id'] . '_' . $record['service_id'];
 
     // last_check
-    $valueLastCheck = (int) $row['last_check'];
+    $valueLastCheck = (int) $record['last_check'];
     $valueLastCheckTimestamp = time() - $valueLastCheck;
     if (
         $valueLastCheckTimestamp > 0
@@ -463,7 +521,7 @@ while ($row = $res->fetch()) {
     $data[$dataKey]['last_check'] = $valueLastCheck;
 
     // last_state_change
-    $valueLastState = (int) $row['last_state_change'];
+    $valueLastState = (int) $record['last_state_change'];
     if ($valueLastState > 0) {
         $valueLastStateTimestamp = time() - $valueLastState;
         $valueLastState = CentreonDuration::toString($valueLastStateTimestamp) . ' ago';
@@ -473,7 +531,7 @@ while ($row = $res->fetch()) {
     $data[$dataKey]['last_state_change'] = $valueLastState;
 
     // last_hard_state_change
-    $valueLastHardState = (int) $row['last_hard_state_change'];
+    $valueLastHardState = (int) $record['last_hard_state_change'];
     if ($valueLastHardState > 0) {
         $valueLastHardStateTimestamp = time() - $valueLastHardState;
         $valueLastHardState = CentreonDuration::toString($valueLastHardStateTimestamp) . ' ago';
@@ -483,44 +541,44 @@ while ($row = $res->fetch()) {
     $data[$dataKey]['last_hard_state_change'] = $valueLastHardState;
 
     // check_attempt
-    $valueCheckAttempt = $row['check_attempt'] . '/'
-        . $row['max_check_attempts'] . ' (' . $aStateType[$row['state_type']] . ')';
+    $valueCheckAttempt = $record['check_attempt'] . '/'
+        . $record['max_check_attempts'] . ' (' . $aStateType[$record['state_type']] . ')';
     $data[$dataKey]['check_attempt'] = $valueCheckAttempt;
 
     // s_state
-    $data[$dataKey]['color'] = $stateSColors[$row['s_state']];
-    $data[$dataKey]['s_state'] = $stateLabels[$row['s_state']];
+    $data[$dataKey]['color'] = $stateSColors[$record['s_state']];
+    $data[$dataKey]['s_state'] = $stateLabels[$record['s_state']];
 
     // h_state
-    $value = $data[$dataKey]['hcolor'] = $stateHColors[$row['h_state']];
-    $data[$dataKey]['h_state'] = $stateLabels[$row['h_state']];
+    $value = $data[$dataKey]['hcolor'] = $stateHColors[$record['h_state']];
+    $data[$dataKey]['h_state'] = $stateLabels[$record['h_state']];
 
     // output
-    $data[$dataKey]['output'] = htmlspecialchars(substr($row['output'], 0, $outputLength));
+    $data[$dataKey]['output'] = htmlspecialchars(substr($record['output'], 0, $outputLength));
 
     $kernel = App\Kernel::createForWeb();
     $resourceController = $kernel->getContainer()->get(
         Centreon\Application\Controller\MonitoringResourceController::class
     );
     $data[$dataKey]['h_details_uri'] = $useDeprecatedPages
-        ? '../../main.php?p=20202&o=hd&host_name=' . $row['hostname']
-        : $resourceController->buildHostDetailsUri($row['host_id']);
+        ? '../../main.php?p=20202&o=hd&host_name=' . $record['hostname']
+        : $resourceController->buildHostDetailsUri($record['host_id']);
 
     $data[$dataKey]['s_details_uri'] = $useDeprecatedPages
-        ? '../../main.php?p=20201&o=svcd&host_name=' . $row['hostname']
-            . '&service_description=' . $row['description']
-        : $resourceController->buildServiceDetailsUri($row['host_id'], $row['service_id']);
+        ? '../../main.php?p=20201&o=svcd&host_name=' . $record['hostname']
+            . '&service_description=' . $record['description']
+        : $resourceController->buildServiceDetailsUri($record['host_id'], $record['service_id']);
 
     $data[$dataKey]['s_graph_uri'] = $useDeprecatedPages
-        ? '../../main.php?p=204&mode=0&svc_id=' . $row['hostname'] . ';' . $row['description']
+        ? '../../main.php?p=204&mode=0&svc_id=' . $record['hostname'] . ';' . $record['description']
         : $resourceController->buildServiceUri(
-            $row['host_id'],
-            $row['service_id'],
+            $record['host_id'],
+            $record['service_id'],
             $resourceController::TAB_GRAPH_NAME
         );
 
     // h_action_url
-    $valueHActionUrl = $row['h_action_url'];
+    $valueHActionUrl = $record['h_action_url'];
     if ($valueHActionUrl) {
         if (preg_match('#^\./(.+)#', $valueHActionUrl, $matches)) {
             $valueHActionUrl = '../../' . $matches[1];
@@ -530,7 +588,7 @@ while ($row = $res->fetch()) {
 
         $valueHActionUrl = CentreonUtils::escapeSecure(
             $hostObj->replaceMacroInString(
-                $row['hostname'],
+                $record['hostname'],
                 $valueHActionUrl
             )
         );
@@ -538,7 +596,7 @@ while ($row = $res->fetch()) {
     }
 
     // h_notes_url
-    $valueHNotesUrl = $row['h_notes_url'];
+    $valueHNotesUrl = $record['h_notes_url'];
     if ($valueHNotesUrl) {
         if (preg_match('#^\./(.+)#', $valueHNotesUrl, $matches)) {
             $valueHNotesUrl = '../../' . $matches[1];
@@ -548,7 +606,7 @@ while ($row = $res->fetch()) {
 
         $valueHNotesUrl = CentreonUtils::escapeSecure(
             $hostObj->replaceMacroInString(
-                $row['hostname'],
+                $record['hostname'],
                 $valueHNotesUrl
             )
         );
@@ -556,7 +614,7 @@ while ($row = $res->fetch()) {
     }
 
     // s_action_url
-    $valueSActionUrl = $row['s_action_url'];
+    $valueSActionUrl = $record['s_action_url'];
     if ($valueSActionUrl) {
         if (preg_match('#^\./(.+)#', $valueSActionUrl, $matches)) {
             $valueSActionUrl = '../../' . $matches[1];
@@ -564,18 +622,18 @@ while ($row = $res->fetch()) {
             $valueSActionUrl = '//' . $valueSActionUrl;
         }
         $valueSActionUrl = CentreonUtils::escapeSecure($hostObj->replaceMacroInString(
-            $row['hostname'],
+            $record['hostname'],
             $valueSActionUrl
         ));
         $valueSActionUrl = CentreonUtils::escapeSecure($svcObj->replaceMacroInString(
-            $row['service_id'],
+            $record['service_id'],
             $valueSActionUrl
         ));
         $data[$dataKey]['s_action_url'] = $valueSActionUrl;
     }
 
     // s_notes_url
-    $valueSNotesUrl = $row['s_notes_url'];
+    $valueSNotesUrl = $record['s_notes_url'];
     if ($valueSNotesUrl) {
         if (preg_match('#^\./(.+)#', $valueSNotesUrl, $matches)) {
             $valueSNotesUrl = '../../' . $matches[1];
@@ -583,11 +641,11 @@ while ($row = $res->fetch()) {
             $valueSNotesUrl = '//' . $valueSNotesUrl;
         }
         $valueSNotesUrl = CentreonUtils::escapeSecure($hostObj->replaceMacroInString(
-            $row['hostname'],
+            $record['hostname'],
             $valueSNotesUrl
         ));
         $valueSNotesUrl = CentreonUtils::escapeSecure($svcObj->replaceMacroInString(
-            $row['service_id'],
+            $record['service_id'],
             $valueSNotesUrl
         ));
         $data[$dataKey]['s_notes_url'] = $valueSNotesUrl;
@@ -595,7 +653,7 @@ while ($row = $res->fetch()) {
 
     // criticality_id
     if ($value != '') {
-        $critData = $criticality->getData($row['criticality_id'], 1);
+        $critData = $criticality->getData($record['criticality_id'], 1);
 
         // get criticality icon path
         $valueCriticalityId = '';
@@ -607,19 +665,21 @@ while ($row = $res->fetch()) {
         $data[$dataKey]['criticality_id'] = $valueCriticalityId;
     }
 
+    // FIXME: A SQL REQUEST IS PLAYED ON EACH LINE TO GET THE COMMENTS !!!!!!
+    // Meaning that for 100 results on which a comment has been set we get 100 SQL requests...
     if (isset($preferences['display_last_comment']) && $preferences['display_last_comment']) {
         $commentSql = 'SELECT 1 AS REALTIME, data FROM comments';
         $comment = '-';
 
-        if ((int) $row['s_acknowledged'] === 1) { // Service is acknowledged
+        if ((int) $record['s_acknowledged'] === 1) { // Service is acknowledged
             $commentSql = 'SELECT 1 AS REALTIME, comment_data AS data FROM acknowledgements';
-        } elseif ((int) $row['s_scheduled_downtime_depth'] === 1) { // Service is in downtime
+        } elseif ((int) $record['s_scheduled_downtime_depth'] === 1) { // Service is in downtime
             $commentSql = 'SELECT 1 AS REALTIME, comment_data AS data FROM downtimes';
         }
 
-        $commentSql .= ' WHERE host_id = ' . $row['host_id'] . ' AND service_id = ' . $row['service_id'];
+        $commentSql .= ' WHERE host_id = ' . $record['host_id'] . ' AND service_id = ' . $record['service_id'];
         $commentSql .= ' ORDER BY entry_time DESC LIMIT 1';
-        $commentResult = $dbb->query($commentSql);
+        $commentResult = $realtimeDatabase->query($commentSql);
 
         while ($commentRow = $commentResult->fetch()) {
             $comment = substr($commentRow['data'], 0, $commentLength);
@@ -634,9 +694,6 @@ while ($row = $res->fetch()) {
     $data[$dataKey]['encoded_hostname'] = urlencode($data[$dataKey]['hostname']);
 }
 
-$autoRefresh = (isset($preferences['refresh_interval']) && (int) $preferences['refresh_interval'] > 0)
-    ? (int) $preferences['refresh_interval']
-    : 30;
 $template->assign('widgetId', $widgetId);
 $template->assign('autoRefresh', $autoRefresh);
 $template->assign('preferences', $preferences);
