@@ -20,6 +20,7 @@
  */
 
 require_once '../require.php';
+require_once '../widget-error-handling.php';
 require_once $centreon_path . 'bootstrap.php';
 require_once $centreon_path . 'www/class/centreon.class.php';
 require_once $centreon_path . 'www/class/centreonSession.class.php';
@@ -31,7 +32,11 @@ if (! isset($_SESSION['centreon']) || ! isset($_REQUEST['widgetId'])) {
     exit;
 }
 $centreon = $_SESSION['centreon'];
-$widgetId = filter_var($_REQUEST['widgetId'], FILTER_VALIDATE_INT);
+
+$widgetId = filter_var(
+    $_REQUEST['widgetId'],
+    FILTER_VALIDATE_INT,
+);
 
 try {
     if ($widgetId === false) {
@@ -40,12 +45,13 @@ try {
 
     global $pearDB;
 
-    $db_centreon = $dependencyInjector['configuration_db'];
-    $db = $dependencyInjector['realtime_db'];
-    $pearDB = $db_centreon;
-    $widgetObj = new CentreonWidget($centreon, $db_centreon);
+    $configurationDatabase = $dependencyInjector['configuration_db'];
+    $widgetObj = new CentreonWidget($centreon, $configurationDatabase);
     $preferences = $widgetObj->getWidgetPreferences($widgetId);
-    $autoRefresh = filter_var($preferences['refresh_interval'], FILTER_VALIDATE_INT);
+    $autoRefresh = filter_var(
+        $preferences['refresh_interval'],
+        FILTER_VALIDATE_INT,
+    );
     $variablesThemeCSS = match ($centreon->user->theme) {
         'light' => 'Generic-theme',
         'dark' => 'Centreon-Dark',
@@ -54,8 +60,19 @@ try {
     if ($autoRefresh === false || $autoRefresh < 5) {
         $autoRefresh = 30;
     }
-} catch (Exception $e) {
-    echo $e->getMessage() . '<br/>';
+    $theme = $variablesThemeCSS === 'Generic-theme'
+        ? $variablesThemeCSS . '/Variables-css'
+        : $variablesThemeCSS;
+} catch (Exception $exception) {
+    CentreonLog::create()->error(
+        logTypeId: CentreonLog::TYPE_BUSINESS_LOG,
+        message: 'Error fetching data for servicegroup-monitoring widget: ' . $exception->getMessage(),
+        customContext: [
+            'widget_id' => $widgetId,
+        ],
+        exception: $exception
+    );
+    showError($exception->getMessage(), $theme ?? 'Generic-theme/Variables-css');
 
     exit;
 }
